# coding: utf-8

"""
    AI Hub API

    The AI Hub REST API. Please see https://docs.instabase.com for more details.

    The version of the OpenAPI document: 0.1
    Contact: support@instabase.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictBool, StrictStr, field_validator
from pydantic import Field
from aihub.models.raise_query_request_source_app_inner import RaiseQueryRequestSourceAppInner
try:
  from typing import Self
except ImportError:
  from typing_extensions import Self


class RaiseQueryRequest(BaseModel):
  """
    RaiseQueryRequest
    """

  # noqa: E501
  query: StrictStr = Field(description="The query to ask the chatbot.")
  model_name: Optional[StrictStr] = Field(
      default=None,
      description="The model could be either 'multistep' or 'multistep-lite'.")
  include_source_info: Optional[StrictBool] = Field(
      default=None,
      description=
      "Set this variable 'true' to get source documents from which the response is fetched."
  )
  source_app: List[RaiseQueryRequestSourceAppInner] = Field(
      description="Source information of the source app.")
  __properties: ClassVar[List[str]] = [
      "query", "model_name", "include_source_info", "source_app"
  ]

  @field_validator('model_name')
  def model_name_validate_enum(cls, value):
    """Validates the enum"""
    if value is None:
      return value

    if value not in ('multistep', 'multistep-lite'):
      raise ValueError(
          "must be one of enum values ('multistep', 'multistep-lite')")
    return value

  model_config = {"populate_by_name": True, "validate_assignment": True}

  def to_str(self) -> str:
    """Returns the string representation of the model using alias"""
    return pprint.pformat(self.model_dump(by_alias=True))

  def to_json(self) -> str:
    """Returns the JSON representation of the model using alias"""
    # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
    return json.dumps(self.to_dict())

  @classmethod
  def from_json(cls, json_str: str) -> Self:
    """Create an instance of RaiseQueryRequest from a JSON string"""
    return cls.from_dict(json.loads(json_str))

  def to_dict(self) -> Dict[str, Any]:
    """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
    _dict = self.model_dump(
        by_alias=True,
        exclude={},
        exclude_none=True,
    )
    # override the default output from pydantic by calling `to_dict()` of each item in source_app (list)
    _items = []
    if self.source_app:
      for _item in self.source_app:
        if _item:
          _items.append(_item.to_dict())
      _dict['source_app'] = _items
    return _dict

  @classmethod
  def from_dict(cls, obj: Dict) -> Self:
    """Create an instance of RaiseQueryRequest from a dict"""
    if obj is None:
      return None

    if not isinstance(obj, dict):
      return cls.model_validate(obj)

    _obj = cls.model_validate({
        "query":
        obj.get("query"),
        "model_name":
        obj.get("model_name"),
        "include_source_info":
        obj.get("include_source_info"),
        "source_app": [
            RaiseQueryRequestSourceAppInner.from_dict(_item)
            for _item in obj.get("source_app")
        ] if obj.get("source_app") is not None else None
    })
    return _obj
